"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class TransactionStatusEnum(str, Enum):
    r"""Status of the transaction."""
    UNKNOWN = 'Unknown'
    PENDING = 'Pending'
    VALIDATION_ERROR = 'ValidationError'
    COMPLETED = 'Completed'
    PUSH_ERROR = 'PushError'
